slice_strip_suffix

Macro slice_strip_suffix 

macro_rules! slice_strip_suffix {
    ($s:expr, $suffix:expr) => { ... };
}
Strip a suffix from a slice, returning an Option with the stripped slice on success. This only works for slices of primitive integer types and str.