macro_rules! unwrap_some {
($expr:expr) => { ... };
}Expand description
Takes an Option and returns the unwrapped Some value, or panics if it’s None.
See also unwrap_ok! and expect_some!.
macro_rules! unwrap_some {
($expr:expr) => { ... };
}Takes an Option and returns the unwrapped Some value, or panics if it’s None.
See also unwrap_ok! and expect_some!.