macro_rules! slice_strip_prefix {
($s:expr, $prefix:expr) => { ... };
}Expand description
Strip a prefix from a slice, returning an Option with the stripped slice on success. This only works for slices of primitive integer types and str.
macro_rules! slice_strip_prefix {
($s:expr, $prefix:expr) => { ... };
}Strip a prefix from a slice, returning an Option with the stripped slice on success. This only works for slices of primitive integer types and str.